﻿using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows.Forms;

using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace TEST {
  public partial class Mainform : Form {

    public Mainform() {
      InitializeComponent();
    }

    void Mainform_Load(object sender, EventArgs e) {
      map.MapUnit = GeographyUnit.Meter;

      // Define Editoverlay
      map.EditOverlay = new EditInteractiveOverlay();
      map.EditOverlay.CanDrag = true;
      map.EditOverlay.CanResize = false;
      map.EditOverlay.CanRotate = false;
      map.EditOverlay.CanReshape = false;
      map.EditOverlay.FeatureDragged += EditOverlay_RectangleDragged;

      // Define shape to be contained in EditOverlay
      SetMapFrame();

      map.Refresh();
    }

    // Recreate shape in EditOverlay, based on size/position in textboxes.
    void SetMapFrame() {
      double X, Y, W2, H2;
      Feature rectangle;

      X = Convert.ToDouble(txtCenterE.Text);
      Y = Convert.ToDouble(txtCenterN.Text);
      W2 = Convert.ToDouble(txtWidth.Text)/2.0;
      H2 = Convert.ToDouble(txtHeight.Text)/2.0;

      rectangle = new Feature(new RectangleShape(X-W2, Y+H2, X+W2, Y-H2));
      map.EditOverlay.EditShapesLayer.InternalFeatures.Clear();
      map.EditOverlay.EditShapesLayer.InternalFeatures.Add(rectangle);
      map.EditOverlay.EditShapesLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle =  AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Orange, GeoColor.SimpleColors.Red, 2, LineDashStyle.Solid);
      map.EditOverlay.EditShapesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
      map.EditOverlay.CalculateAllControlPoints();
    }

    // Event caused by user dragging shape
    void EditOverlay_RectangleDragged(object sender, FeatureDraggedEditInteractiveOverlayEventArgs e) {
      if (e.DraggedFeature == null) return;
      PolygonShape rect = (PolygonShape)e.DraggedFeature.GetShape();
      PointShape center = rect.GetCenterPoint();
      // Update text box position from shape position
      txtCenterE.Text = center.X.ToString();
      txtCenterN.Text = center.Y.ToString();
    }

    // Event caused by user leaving a textbox
    void txtBox_Validated(object sender, EventArgs e) {
      SetMapFrame(); // Applies changes in size/position to shape
      map.Refresh();
    }

  }

}
